Momapy - momapy

Skip to content

# Momapy

## `` momapy

Library for working with molecular maps programmatically

Modules:

Name | Description
--- | ---
`builder` | Classes and functions for building maps and map elements
`celldesigner` | Subpackage for CellDesigner maps
`coloring` | Classes and objects for defining colors
`core` | Base classes for core components defining maps and their elements
`drawing` | Classes and objects for drawing elements (SVG-like)
`geometry` | Classes and functions for geometry
`io` | Base classes and functions for reading and writing maps
`meta` |
`monitoring` |
`positioning` | Functions for positioning layout elements and related objects relatively to other objects
`rendering` | Subpackage for rendering
`sbgn` | Subpackage for SBGN maps
`sbml` | Subpackge for SBML maps (skeleton)
`styling` | Classes and functions for styling layout elements using style sheets